/**********************************************************************
Copyright (c) 2006 Andy Jefferson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    ...
**********************************************************************/
package org.jpox;

import javax.jdo.JDOHelper;
import javax.jdo.JDOUserException;
import javax.jdo.PersistenceManager;
import javax.jdo.spi.PersistenceCapable;

import org.jpox.metadata.AbstractClassMetaData;
import org.jpox.state.StateManagerFactory;
import org.jpox.util.Localiser;

/**
 * Helper for persistence operations with JPOX.
 * Extends JDOHelper so that people can use JPOXHelper if they wish.
 * 
 * @version $Revision: 1.2 $
 */
public class JPOXHelper extends JDOHelper
{
    /** Localisation utility for output messages */
    protected static final Localiser LOCALISER = Localiser.getInstance("org.jpox.Localisation");

    /**
     * Method to return the names of all fields that are currently dirty in the
     * passed detached object.
     * TODO Try to remove the need for the PM. We currently use it to generate the temporary StateManager
     * @param obj The PersistenceCapable (detached)
     * @param pm PersistenceManager to use
     * @return Names of the fields that are dirty
     * @throws JDOUserException Thrown if the object is not detached
     */
    public static String[] getDetachedObjectDirtyFields(Object obj, PersistenceManager pm)
    {
        if (obj == null)
        {
            return null;
        }
        if (!isDetached(obj))
        {
            throw new JDOUserException(LOCALISER.msg("PM.ObjectNotDetached"));
        }

        // Create a StateManager to give us a means of extracting the detached info
        PersistenceCapable pc = (PersistenceCapable)obj;
        org.jpox.PersistenceManager thePM = (org.jpox.PersistenceManager)pm;
        AbstractClassMetaData acmd = thePM.getMetaDataManager().getMetaDataForClass(pc.getClass(), thePM.getClassLoaderResolver());
        StateManager sm = StateManagerFactory.newStateManager(thePM.getPMFContext().getApiAdapter(), pc, acmd, getObjectId(pc), null);
        pc.jdoReplaceStateManager(sm); // Assign this StateManager to our detached object
        sm.retrieveDetachState(sm);
        String[] dirtyFieldNames = sm.getDirtyFieldNames();
        pc.jdoReplaceStateManager(null); // Remove the StateManager from our detached object

        return dirtyFieldNames;
    }

    /**
     * Method to return the names of all fields that are currently loaded in the
     * passed detached object.
     * TODO Try to remove the need for the PM. We currently use it to generate the temporary StateManager
     * @param obj The PersistenceCapable (detached)
     * @param pm PersistenceManager to use
     * @return Names of the fields that are loaded
     * @throws JDOUserException Thrown if the object is not detached
     */
    public static String[] getDetachedObjectLoadedFields(Object obj, PersistenceManager pm)
    {
        if (obj == null)
        {
            return null;
        }
        if (!isDetached(obj))
        {
            throw new JDOUserException(LOCALISER.msg("PM.ObjectNotDetached"));
        }

        // Create a StateManager to give us a means of extracting the detached info
        PersistenceCapable pc = (PersistenceCapable)obj;
        org.jpox.PersistenceManager thePM = (org.jpox.PersistenceManager)pm;
        AbstractClassMetaData acmd = thePM.getMetaDataManager().getMetaDataForClass(pc.getClass(), thePM.getClassLoaderResolver());
        StateManager sm = StateManagerFactory.newStateManager(thePM.getPMFContext().getApiAdapter(), pc, acmd, getObjectId(pc), null);
        pc.jdoReplaceStateManager(sm); // Assign this StateManager to our detached object
        sm.retrieveDetachState(sm);
        String[] loadedFieldNames = sm.getLoadedFieldNames();
        pc.jdoReplaceStateManager(null); // Remove the StateManager from our detached object

        return loadedFieldNames;
    }
}