/**********************************************************************
Copyright (c) 2005 Andy Jefferson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License. 


Contributors:
    ...
**********************************************************************/
package org.jpox.cache;

import javax.jdo.spi.PersistenceCapable;

/**
 * An object that is stored in the Level2 Cache.
 * Comprises a PersistenceCapable object, and its loaded fields array
 * so we know which fields are loaded when we retrieve it from the cache.
 * 
 * @version $Revision: 1.3 $
 */
public class CachedPC
{
    /** The PersistenceCapable object */
    private PersistenceCapable pc;

    /** The loaded fields array */
    private boolean[] loadedFields;

    /**
     * Constructor.
     * @param pc The PersistenceCapable object
     * @param loadedFields The loaded fields
     */
    public CachedPC(PersistenceCapable pc, boolean[] loadedFields)
    {
        this.pc = pc;
        this.loadedFields = new boolean[loadedFields.length];
        for (int i=0;i<loadedFields.length;i++)
        {
            this.loadedFields[i] = loadedFields[i];
        }
    }

    /**
     * Accessor for the PersistenceCapable object
     * @return The PC object
     */
    public PersistenceCapable getPersistenceCapable()
    {
        return pc;
    }

    /**
     * Accessor for the class of the PC object.
     * @return The class of the object
     */
    public Class getPCClass()
    {
        return pc.getClass();
    }

    /**
     * Accessor for the loaded fields of this object
     * @return The loaded fields
     */
    public boolean[] getLoadedFields()
    {
        return loadedFields;
    }
}