/**********************************************************************
Copyright (c) 2004 Andy Jefferson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License. 


Contributors:
    ...
**********************************************************************/
package org.jpox.cache;

import javax.jdo.datastore.DataStoreCache.EmptyDataStoreCache;

/**
 * Null implementation of a Level 2 Cache.
 * Exists to meet the JDO 2 spec which states that the PMF will return a
 * DataStoreCache that silently does nothing when its methods are called.
 * Extends the JDO2 spec provided EmptyDataStoreCache to provide the add-on JPOX methods.
 * 
 * @version $Revision: 1.7 $
 */
public class NullLevel2Cache extends EmptyDataStoreCache implements Level2Cache
{
    /**
     * 
     * @see org.jpox.cache.Level2Cache#clear()
     */
    public void clear()
    {
    }

    /**
     * 
     * @see org.jpox.cache.Level2Cache#containsOid(java.lang.Object)
     */
    public boolean containsOid(Object oid)
    {
        return false;
    }

    /**
     * Accessor for an object from the cache
     * @param oid The identity
     * @return The cacheable object
     */
    public CachedPC get(Object oid)
    {
        return null;
    }

    /**
     * 
     * @see org.jpox.cache.Level2Cache#getNumberOfPinnedObjects()
     */
    public int getNumberOfPinnedObjects()
    {
        return 0;
    }

    /**
     * 
     * @see org.jpox.cache.Level2Cache#getNumberOfUnpinnedObjects()
     */
    public int getNumberOfUnpinnedObjects()
    {
        return 0;
    }

    /**
     * 
     * @see org.jpox.cache.Level2Cache#getSize()
     */
    public int getSize()
    {
        return 0;
    }

    /**
     * 
     * @see org.jpox.cache.Level2Cache#isEmpty()
     */
    public boolean isEmpty()
    {
        return false;
    }

    /**
     * Method to put an object in the L2 cache
     * @param oid The identity
     * @param pc Cacheable form of the PC
     * @return Previous value stored for this id
     */
    public CachedPC put(Object oid, CachedPC pc)
    {
        return null;
    }
}