/**********************************************************************
Copyright (c) 2006 Erik Bengtson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
     ...
***********************************************************************/
package org.jpox.management;

import java.io.Serializable;

public class ManagementCategory implements Serializable
{
    private static final int MANAGEMENT_CATEGORY_DATASTORE_ERROR = 100;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_WARNING = 101;

    //Datastore requests management
/*    private static final int MANAGEMENT_CATEGORY_STATE_TRANSIENT = 200;
    private static final int MANAGEMENT_CATEGORY_STATE_P_NEW = 201;
    private static final int MANAGEMENT_CATEGORY_STATE_P_CLEAN = 202;
    private static final int MANAGEMENT_CATEGORY_STATE_P_DIRTY = 203;
    private static final int MANAGEMENT_CATEGORY_STATE_HOLLOW = 204;
    private static final int MANAGEMENT_CATEGORY_STATE_T_CLEAN = 205;
    private static final int MANAGEMENT_CATEGORY_STATE_T_DIRTY = 206;
    private static final int MANAGEMENT_CATEGORY_STATE_P_NEW_DELETED = 207;
    private static final int MANAGEMENT_CATEGORY_STATE_P_DELETED = 208;
    private static final int MANAGEMENT_CATEGORY_STATE_P_NONTRANS = 209;
    private static final int MANAGEMENT_CATEGORY_STATE_DETACHED_CLEAN = 210;
    private static final int MANAGEMENT_CATEGORY_STATE_DETACHED_DIRTY = 211;

    //Datastore requests management
    private static final int MANAGEMENT_CATEGORY_DATASTORE_REQUEST_FCO_FETCH = 300;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_REQUEST_FCO_FETCH_ERROR = 300;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_REQUEST_FCO_INSERT = 301;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_REQUEST_FCO_INSERT_ERROR = 301;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_REQUEST_FCO_UPDATE = 302;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_REQUEST_FCO_UPDATE_ERROR = 302;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_REQUEST_SCO_FETCH = 300;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_REQUEST_SCO_FETCH_ERROR = 300;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_REQUEST_SCO_INSERT = 301;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_REQUEST_SCO_INSERT_ERROR = 301;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_REQUEST_SCO_UPDATE = 302;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_REQUEST_SCO_UPDATE_ERROR = 302;
    
    //Query management
    private static final int MANAGEMENT_CATEGORY_QUERY = 400;
    private static final int MANAGEMENT_CATEGORY_QUERY_RESULTS_CACHE_HIT = 401;
    
    //cache (1st level cache) management
    private static final int MANAGEMENT_CATEGORY_CACHE_HIT = 500;
    private static final int MANAGEMENT_CATEGORY_CACHE_MISS = 501;
    private static final int MANAGEMENT_CATEGORY_CACHE_COUNT = 502;

    //Datastore cache (2nd level cache) management
    private static final int MANAGEMENT_CATEGORY_DATASTORECACHE_HIT = 530;
    private static final int MANAGEMENT_CATEGORY_DATASTORECACHE_MISS = 531;
    private static final int MANAGEMENT_CATEGORY_DATASTORECACHE_COUNT = 532;

    //SCO cache management
    private static final int MANAGEMENT_CATEGORY_SCOCACHE_HIT = 560;
    private static final int MANAGEMENT_CATEGORY_SCOCACHE_MISS = 561;
    private static final int MANAGEMENT_CATEGORY_SCOCACHE_COUNT = 562;
    
    //Transaction management
    private static final int MANAGEMENT_CATEGORY_TRANSACTION_COUNT = 700;
    private static final int MANAGEMENT_CATEGORY_TRANSACTION_COMMIT = 701;
    private static final int MANAGEMENT_CATEGORY_TRANSACTION_ROLLBACK = 702;
    private static final int MANAGEMENT_CATEGORY_TRANSACTION_TIME = 703;
    
    //Optimistic transaction management
    private static final int MANAGEMENT_CATEGORY_TRANSACTION_OPTIMISTIC_COUNT = 800;
    private static final int MANAGEMENT_CATEGORY_TRANSACTION_OPTIMISTIC_COMMIT = 801;
    private static final int MANAGEMENT_CATEGORY_TRANSACTION_OPTIMISTIC_ROLLBACK = 802;
    private static final int MANAGEMENT_CATEGORY_TRANSACTION_OPTIMISTIC_TIME = 803;

    //SCHEMA management
    private static final int MANAGEMENT_CATEGORY_DATASTORE_RBDMS_TABLE_VALIDATION_COUNT = 900;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_RBDMS_TABLE_VALID = 901;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_RBDMS_TABLE_INVALID = 902;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_RBDMS_CONSTRAINT_VALIDATION_COUNT = 903;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_RBDMS_CONSTRAINT_VALID = 904;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_RBDMS_CONSTRAINT_INVALID = 905;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_RBDMS_TABLE_CREATION_COUNT = 906;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_RBDMS_TABLE_CREATION_SUCCEEDED = 907;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_RBDMS_TABLE_CREATION_FAILED = 908;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_RBDMS_CONSTRAINT_CREATION_COUNT = 909;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_RBDMS_CONSTRAINT_CREATION_SUCCEEDED = 910;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_RBDMS_CONSTRAINT_CREATION_FAILED = 911;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_RBDMS_TABLE_ALTER_COUNT = 912;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_RBDMS_TABLE_ALTER_SUCCEEDED = 913;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_RBDMS_TABLE_ALTER_FAILED = 914;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_RBDMS_CONSTRAINT_ALTER_COUNT = 915;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_RBDMS_CONSTRAINT_ALTER_SUCCEEDED = 916;
    private static final int MANAGEMENT_CATEGORY_DATASTORE_RBDMS_CONSTRAINT_ALTER_FAILED = 917;*/

    public static final int MANAGEMENT_CATEGORY_TOTAL = 999;
    
    /** errors thrown by the datastore **/
    public static final ManagementCategory DATASTORE_ERROR = new ManagementCategory(MANAGEMENT_CATEGORY_DATASTORE_ERROR);
    /** warnings thrown by the datastore **/
    public static final ManagementCategory DATASTORE_WARNING = new ManagementCategory(MANAGEMENT_CATEGORY_DATASTORE_WARNING);

    private final int type;

    /**
     * Constructor - private to prevent instantiation.
     * @param type The type of category.
     **/
    private ManagementCategory(int type)
    {
        this.type = type;
    }
    
    /**
     * Accessor for the type of the category
     * @return an index number to the category
     */
    public int getType()
    {
        return type;
    }
}
