/**********************************************************************
Copyright (c) 2006 Erik Bengtson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 

Contributors:
    ...
**********************************************************************/
package org.jpox.plugin;

/**
 * Extension declared in a plug-in. Represents the XML element 
 * @version $Revision: 1.3 $
 */
public class Extension
{
    /** reference to the extension point this extension implements **/
    final private ExtensionPoint point;
    
    /** declared plugin **/
    final private Plugin plugin;
    
    /** Configuration elements **/
    ConfigurationElement[] configurationElement;

    public Extension(ExtensionPoint point, Plugin plugin)
    {
        this.point = point;
        this.plugin = plugin;
        this.configurationElement = new ConfigurationElement[0];
    }
    
    /**
     * Accessor for the Plug-in that declared this Extension
     * @return the Plug-in
     */
    public Plugin getPlugin()
    {
        return plugin;
    }

    /**
     * Acessor for the ExtensionPoint that this Extension implements
     * @return the ExtensionPoint
     */
    public ExtensionPoint getPoint()
    {
        return point;
    }
    
    /**
     * Add a new child ConfigurationElement (declared nested in the extension XML element)
     * @param element the ConfigurationElement
     */
    public void addConfigurationElement(ConfigurationElement element)
    {
        ConfigurationElement[] elms = new ConfigurationElement[configurationElement.length+1];
        System.arraycopy(configurationElement, 0, elms, 0, configurationElement.length);
        elms[configurationElement.length] = element;
        configurationElement = elms;         
    }
    
    /**
     * Acessor for all ConfigurationElements declared in the Extension
     * @return array of ConfigurationElement
     */
    public ConfigurationElement[] getConfigurationElements()
    {
        return configurationElement;
    }
}
