/**********************************************************************
Copyright (c) 2006 Erik Bengtson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 

Contributors:
    ...
**********************************************************************/
package org.jpox.plugin;

import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.net.URL;


/**
 * Loader and registry of Extensions and Extension Points. The implementation
 * of this interface must have a public constructor taking the ClassLoaderResolver 
 * interface as argument 
 * @version $Revision: 1.6 $
 */
public interface PluginRegistry
{

    /**
     * Acessor for the ExtensionPoint
     * @param id the unique id of the extension point
     * @return null if the ExtensionPoint is not registered
     */
    ExtensionPoint getExtensionPoint(String id);

    /**
     * Acessor for the currently registed ExtensionPoints
     * @return array of ExtensionPoints
     */
    ExtensionPoint[] getExtensionPoints();

    /**
     * Register Extension Points declared in /org/jpox/plugin/plugin.xml
     */
    void registerExtensionPoints();

    /**
     * Register ExtensionPoints and Extensions declared in plugin files
     */
    void registerExtensions();
    
    /**
     * Loads a class (do not initialize) from an attribute of {@link ConfigurationElement}
     * @param confElm the configuration element
     * @param name the attribute name
     * @return the Class
     */
    Object createExecutableExtension(ConfigurationElement confElm, String name, Class[] argsClass, Object[] args) throws ClassNotFoundException, SecurityException, NoSuchMethodException, IllegalArgumentException, InstantiationException, IllegalAccessException, InvocationTargetException;

    /**
     * Loads a class (do not initialize)
     * @param pluginId the plugin id
     * @param className the class name
     * @return the Class
     * @throws ClassNotFoundException 
     */
    Class loadClass(String pluginId, String className) throws ClassNotFoundException;
    
    /**
     * Converts a URL that uses a user-defined protocol into a URL that uses the file protocol.
     * @param url the url to be converted
     * @return the converted URL
     * @throws IOException
     */
    URL resolveURLAsFileURL(URL url) throws IOException;
}