/**********************************************************************
Copyright (c) 2003 David Jencks and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
2004 Erik Bengtson - method close is delegated to AbstractPersistenceManagerFactory
2005 Marco Schulze - implemented copying the lifecycle listeners in j2ee environment 
    ...
**********************************************************************/
package org.jpox.resource;

import java.util.Collection;
import java.util.Properties;

import javax.jdo.JDOException;
import javax.jdo.PersistenceManager;
import javax.jdo.PersistenceManagerFactory;
import javax.jdo.datastore.DataStoreCache;
import javax.jdo.listener.InstanceLifecycleListener;
import javax.naming.NamingException;
import javax.naming.Reference;
import javax.resource.ResourceException;
import javax.resource.cci.Connection;
import javax.resource.cci.ConnectionFactory;
import javax.resource.cci.ConnectionSpec;
import javax.resource.cci.RecordFactory;
import javax.resource.cci.ResourceAdapterMetaData;
import javax.resource.spi.ConnectionManager;

import org.jpox.AbstractPersistenceManagerFactory;

/**
 * PersistenceManagerFactoryImpl for J2EE
 * @version $Revision: 1.14 $
 */
public class PersistenceManagerFactoryImpl implements ConnectionFactory, PersistenceManagerFactory
{
    private final ManagedConnectionFactoryImpl mcf;
    private final ConnectionManager cm;

    private Reference ref;

    /**
     * Constructor 
     * @param mcf the ManagedConnectionFactory
     * @param cm the ConnectionManager
     */
    public PersistenceManagerFactoryImpl(final ManagedConnectionFactoryImpl mcf, final ConnectionManager cm) 
    {
        this.mcf = mcf;
        this.cm = cm;      
    }

    /**
     * Accessor to the AbstractPersistenceManagerFactory 
     * @return the AbstractPersistenceManagerFactory
     */
    public AbstractPersistenceManagerFactory getAbstractPersistenceManagerFactory()
    {
         return mcf;
    }

    // implementation of javax.resource.Referenceable interface

    /**
     *
     * @param ref <description>
     */
    public void setReference(Reference ref)
    {
        this.ref = ref;
    }

    // implementation of javax.naming.Referenceable interface

    /**
     *
     * @return <description>
     * @exception javax.naming.NamingException <description>
     */
    public Reference getReference() throws NamingException
    {
        return ref;
    }

    // implementation of javax.resource.cci.ConnectionFactory interface

    /**
     *
     * @return <description>
     * @exception javax.resource.ResourceException <description>
     */
    public Connection getConnection() throws ResourceException
    {
        return (Connection)cm.allocateConnection(mcf, null);
    }

    /**
     *
     * @param cs <description>
     * @return <description>
     * @exception javax.resource.ResourceException <description>
     */
    public Connection getConnection(ConnectionSpec cs) throws ResourceException
    {
        return getConnection();
    }

    /**
     *
     * @return <description>
     * @exception javax.resource.ResourceException <description>
     */
    public ResourceAdapterMetaData getMetaData() throws ResourceException
    {
        throw new ResourceException("Not Yet Implemented");
    }

    /**
     *
     * @return <description>
     * @exception javax.resource.ResourceException <description>
     */
    public RecordFactory getRecordFactory() throws ResourceException
    {
        return null;
    }

    // implementation of javax.jdo.PersistenceManagerFactory interface

    /**
     *
     * @return <description>
     */
    public Properties getProperties()
    {
        throw new JDOException("Not available in managed environment");
    }

    /**
     *
     * @return <description>
     */
    public PersistenceManager getPersistenceManager()
    {
        try 
        {
            return (PersistenceManager)getConnection();
        }
        catch (ResourceException e)
        {
            throw new JDOException("Problem getting PersistenceManager:", new Exception[] {e});
        }
    }

    /**
     *
     * @param user Username
     * @param pw password
     * @return PersistenceManager
     */
    public PersistenceManager getPersistenceManager(String user, String pw)
    {
        throw new JDOException("Not available in managed environment");
    }

    /**
     * Mutator for the Username 
     *
     * @param username Username
     */
    public void setConnectionUserName(String username)
    {
        throw new JDOException("Not available in managed environment");
    }

    /**
     * Accessor for the username 
     *
     * @return Username
     */
    public String getConnectionUserName()
    {
        throw new JDOException("Not available in managed environment");
    }

    /**
     * Mutator for the Password 
     *
     * @param password Password
     */
    public void setConnectionPassword(String password)
    {
        throw new JDOException("Not available in managed environment");
    }

    /**
     * Mutator for the connection URL 
     *
     * @param url Connection URL for the datasource
     */
    public void setConnectionURL(String url)
    {
        throw new JDOException("Not available in managed environment");
    }

    /**
     * Accessor for the connection URL 
     *
     * @return The connection URL
     */
    public String getConnectionURL()
    {
        throw new JDOException("Not available in managed environment");
    }

    /**
     *
     * @param drivername Driver name
     */
    public void setConnectionDriverName(String drivername)
    {
        throw new JDOException("Not available in managed environment");
    }

    /**
     *
     * @return The connection driver name
     */
    public String getConnectionDriverName()
    {
        throw new JDOException("Not available in managed environment");
    }

    /**
     *
     * @param conn_factory_name <description>
     */
    public void setConnectionFactoryName(String conn_factory_name)
    {
        throw new JDOException("Not available in managed environment");
    }

    /**
     *
     * @return Connection Factory name
     */
    public String getConnectionFactoryName()
    {
        throw new JDOException("Not available in managed environment");
    }

    /**
     *
     * @param conn_factory Connection factory
     */
    public void setConnectionFactory(Object conn_factory)
    {
        throw new JDOException("Not available in managed environment");
    }

    /**
     *
     * @return The connection factory
     */
    public Object getConnectionFactory()
    {
        throw new JDOException("Not available in managed environment");
    }

    /**
     *
     * @param conn_factory_name Connection factory name
     */
    public void setConnectionFactory2Name(String conn_factory_name)
    {
        throw new JDOException("Not available in managed environment");
    }

    /**
     *
     * @return Connection factory name
     */
    public String getConnectionFactory2Name()
    {
        throw new JDOException("Not available in managed environment");
    }

    /**
     *
     * @param conn_factory Connection Factory
     */
    public void setConnectionFactory2(Object conn_factory)
    {
        throw new JDOException("Not available in managed environment");
    }

    /**
     *
     * @return <description>
     */
    public Object getConnectionFactory2()
    {
        throw new JDOException("Not available in managed environment");
    }

    /**
     *
     * @param multithreaded Whether is multithreaded or not
     */
    public void setMultithreaded(boolean multithreaded)
    {
        mcf.setMultithreaded(multithreaded);
    }

    /**
     *
     * @return <description>
     */
    public boolean getMultithreaded()
    {
        return mcf.getMultithreaded();
    }

    /**
     *
     * @param optimistic <description>
     */
    public void setOptimistic(boolean optimistic)
    {
        mcf.setOptimistic(optimistic);
    }

    /**
     *
     * @return <description>
     */
    public boolean getOptimistic()
    {
        return mcf.getOptimistic();
    }

    /**
     *
     * @param retain_values <description>
     */
    public void setRetainValues(boolean retain_values)
    {
        mcf.setRetainValues(retain_values);
    }

    /**
     *
     * @return <description>
     */
    public boolean getRetainValues()
    {
        return mcf.getRetainValues();
    }

    /**
     *
     * @param restore_values <description>
     */
    public void setRestoreValues(boolean restore_values)
    {
        mcf.setRestoreValues(restore_values);
    }

    /**
     *
     * @return <description>
     */
    public boolean getRestoreValues()
    {
        return mcf.getRestoreValues();
    }

    /**
     *
     * @param nontrans_read <description>
     */
    public void setNontransactionalRead(boolean nontrans_read)
    {
        mcf.setNontransactionalRead(nontrans_read);
    }

    /**
     *
     * @return <description>
     */
    public boolean getNontransactionalRead()
    {
        return mcf.getNontransactionalRead();
    }

    /**
     *
     * @param nontrans_write <description>
     */
    public void setNontransactionalWrite(boolean nontrans_write)
    {
        mcf.setNontransactionalWrite(nontrans_write);
    }

    /**
     *
     * @return <description>
     */
    public boolean getNontransactionalWrite()
    {
        return mcf.getNontransactionalWrite();
    }

    /**
     *
     * @param ignore <description>
     */
    public void setIgnoreCache(boolean ignore)
    {
        mcf.setIgnoreCache(ignore);
    }

    /**
     *
     * @return <description>
     */
    public boolean getIgnoreCache()
    {
        return mcf.getIgnoreCache();
    }

    /**
     * Mutator for whether to detach objects on close of the PM's
     * @param detach Whether to detach objects on close of the PM.
     */
    public void setDetachOnClose(boolean detach)
    {
        mcf.setDetachOnClose(detach);
    }

    /**
     * Accessor for whether to detach objects on close of the PM's
     * @return Whether to detach objects on close of the PM's
     */
    public boolean getDetachOnClose()
    {
        return getDetachOnClose();
    }

    /**
     * Mutator for whether to detach all objects on commit of the txn.
     * @param detach Whether to detach objects on commit of the txn.
     */
    public void setDetachAllOnCommit(boolean detach)
    {
        mcf.setDetachAllOnCommit(detach);
    }

    /**
     * Accessor for whether to detach objects on commit of the txn.
     * @return Whether to detach objects on commit of the txn.
     */
    public boolean getDetachAllOnCommit()
    {
        return getDetachAllOnCommit();
    }
    
    /**
     * Mutator for the Mapping name
     * @param mapping mapping name
     */
    public void setMapping(String mapping)
    {
        mcf.setMapping(mapping);
    }
    
    /**
     * Accessor for the mapping name
     * @return mapping name
     */
    public String getMapping()
    {
        return mcf.getMapping();
    }
   
    /**
     * Accessor for the supported options 
     *
     * @return Collection of supported options
     */
    public Collection supportedOptions()
    {
        return mcf.supportedOptions();
    }
    
    /**
     * Accessor for the Datastore Cache
     * @return The datastore cache
     */
    public DataStoreCache getDataStoreCache()
    {
        return mcf.getDataStoreCache();
    }
    
    /**
     * @see javax.jdo.PersistenceManagerFactory#close()
     */
    public void close()
    {
		mcf.close();
    }

    /**
     * Accessor for whether the PMF is closed.
     * @return Whether it is closed.
     */
    public boolean isClosed()
    {
        return mcf.isClosed();
    }

	/**
     * JDO 2.0 spec 12.15 "LifecycleListeners".
     * @param listener The instance lifecycle listener to sends events to
     * @param classes The classes that it is interested in
     * @since 1.1
     */
    public void addInstanceLifecycleListener(InstanceLifecycleListener listener, Class[] classes)
    {
        mcf.addInstanceLifecycleListener(listener, classes);
    }

    /**
     * JDO 2.0 spec 12.15 "LifecycleListeners".
     * @param listener The instance lifecycle listener to remove.
     * @since 1.1
     */
    public void removeInstanceLifecycleListener(InstanceLifecycleListener listener)
    {
        mcf.removeInstanceLifecycleListener(listener);
    }
}