/**********************************************************************
Copyright (c) 2003 Mike Martin and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 

Contributors:
2003 Andy Jefferson - commented
    ...
**********************************************************************/
package org.jpox.sco;

import org.jpox.state.FetchPlanState;

/**
 * Representation of a wrapper/proxy for a mutable SCO type supported by JPOX.
 * 
 * An implementation of this interface must have a constructor with the arguments 
 * <i>{@link org.jpox.StateManager} ownerSM</i>, <i>String fieldName</i> (<i>Constructor({@link org.jpox.StateManager} owner, String fieldName)</i>)
 *
 * @version $Revision: 1.19 $
 **/
public interface SCO
{
    /**
     * Assigns the value of this second-class object from an existing object
     * of the same or compatible type.
     * @param obj the object from which to copy the value.
     * @param forUpdate Whether the object needs updating in the datastore with this value
     * @throws ClassCastException Thrown if the given object is not of a type that's compatible with this
     *                            second-class wrapper object.
     */
    void setValueFrom(Object obj, boolean forUpdate) throws ClassCastException;

    /**
     * Returns the field name.
     * @return field name. Returns null if the SCO instance is not associated with an owner. 
     */
    String getFieldName();

    /**
     * Returns the owner object of the SCO instance. Usually it's an instance of {@link javax.jdo.spi.PersistenceCapable}.
     * <p>
     * Internally, the SCO implementation can obtain the owner instance from the <i>ownerSM.getObject()</i> call.
     * </p>
     * @return owner object
     */
    Object getOwner();

    /**
     * Nullifies references to the owner Object and Field. 
     * <p>
     * As pos-condition, the SCO instance is no longer associated
     * with the owner, thus should not issue any request to the datastore. All references to
     * a {@link org.jpox.StateManager} or {@link javax.jdo.spi.PersistenceCapable} must be released.
     * </p>
     */
    void unsetOwner();

    /**
     * Mutable second class objects are required to provide a public clone
     * method so that copying of PersistenceCapable objects can take place. This
     * mustn't throw a {@link CloneNotSupportedException}.
     * @return A clone of the object
     */
    Object clone();

    /**
     * Method to return a detached copy of this object.
     * Detaches all components of this object that are also PersistenceCapable.
     * @param state State of the detachment process
     * @return The detached copy
     */
    Object detachCopy(FetchPlanState state);

    /**
     * Method to return an attached copy of this object.
     * Attaches all components of this object that are also {@link javax.jdo.spi.PersistenceCapable}.
     * @param value The object value from the detached instance
     */
    void attachCopy(Object value);
}