/**********************************************************************
Copyright (c) 2006 Erik Bengtson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License. 


Contributors:
    ...
**********************************************************************/
package org.jpox.state;

/**
 * CallBack handlers receive notification of events on persistent objects. 
 * Handlers are responsible to invoke event listeners/callback methods on Callback or Listener
 * implementations.
 * 
 * @version $Revision: 1.3 $
 */
public interface CallbackHandler
{
    void postCreate(Object pc);
    void preStore(Object pc);
    void postStore(Object pc);
    void preClear(Object pc);
    void postClear(Object pc);
    void preDelete(Object pc);
    void postDelete(Object pc);
    void preDirty(Object pc);
    void postDirty(Object pc);
    void postLoad(Object pc);
    void postRefresh(Object pc);
    void preDetach(Object pc);
    void postDetach(Object pc,Object detachedPC);
    void preAttach(Object detachedPC);
    void postAttach(Object pc,Object detachedPC);

    /**
     * Adds a new listener to this handler.
     * @param listener the listener instance
     * @param classes the persistent classes which events are fired for the listener  
     */
    void addListener(Object listener, Class[] classes);

    /**
     * Remove a listener for this handler.
     * @param listener the listener instance
     */
    void removeListener(Object listener);

    /**
     * Clear any objects to release resources
     */
    void close();    
}