/**********************************************************************
Copyright (c) 2006 Erik Bengtson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License. 


Contributors:
    ...
**********************************************************************/
package org.jpox.state;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import javax.jdo.listener.AttachCallback;
import javax.jdo.listener.AttachLifecycleListener;
import javax.jdo.listener.ClearCallback;
import javax.jdo.listener.ClearLifecycleListener;
import javax.jdo.listener.CreateLifecycleListener;
import javax.jdo.listener.DeleteCallback;
import javax.jdo.listener.DeleteLifecycleListener;
import javax.jdo.listener.DetachCallback;
import javax.jdo.listener.DetachLifecycleListener;
import javax.jdo.listener.DirtyLifecycleListener;
import javax.jdo.listener.InstanceLifecycleEvent;
import javax.jdo.listener.InstanceLifecycleListener;
import javax.jdo.listener.LoadCallback;
import javax.jdo.listener.LoadLifecycleListener;
import javax.jdo.listener.StoreCallback;
import javax.jdo.listener.StoreLifecycleListener;
import javax.jdo.spi.PersistenceCapable;

import org.jpox.AbstractPersistenceManager;
import org.jpox.FieldInstanceLifecycleEvent;
import org.jpox.LifecycleListenerForClass;
import org.jpox.StateManager;

/**
 * CallbackHandler implementation for JDO 
 */
public class JDOCallbackHandler implements CallbackHandler
{
    List listeners = new ArrayList(1);
    
    public void postAttach(Object pc,Object detachedPC)
    {
        if (detachedPC instanceof AttachCallback)
        {
            ((AttachCallback) pc).jdoPostAttach(detachedPC);
        }
        Iterator iter = listeners.iterator();
        while (iter.hasNext())
        {
            LifecycleListenerForClass listener = (LifecycleListenerForClass) iter.next();
            if (listener.forClass(pc.getClass()) && listener.getListener() instanceof AttachLifecycleListener)
            {
                ((AttachLifecycleListener)listener.getListener()).postAttach(new InstanceLifecycleEvent(pc, InstanceLifecycleEvent.ATTACH, detachedPC));
            }
        }
    }

    public void postClear(Object pc)
    {
        Iterator iter = listeners.iterator();
        while (iter.hasNext())
        {
            LifecycleListenerForClass listener = (LifecycleListenerForClass) iter.next();
            if (listener.forClass(pc.getClass()) && listener.getListener() instanceof ClearLifecycleListener)
            {
                ((ClearLifecycleListener)listener.getListener()).postClear(new InstanceLifecycleEvent(pc, InstanceLifecycleEvent.CLEAR, null));
            }
        }
    }

    public void postCreate(Object pc)
    {
        Iterator iter = listeners.iterator();
        while (iter.hasNext())
        {
            LifecycleListenerForClass listener = (LifecycleListenerForClass) iter.next();
            if (listener.forClass(pc.getClass()) && listener.getListener() instanceof CreateLifecycleListener)
            {
                ((CreateLifecycleListener)listener.getListener()).postCreate(new InstanceLifecycleEvent(pc, InstanceLifecycleEvent.CREATE, null));
            }
        }        
    }

    public void postDelete(Object pc)
    {
        Iterator iter = listeners.iterator();
        while (iter.hasNext())
        {
            LifecycleListenerForClass listener = (LifecycleListenerForClass) iter.next();
            if (listener.forClass(pc.getClass()) && listener.getListener() instanceof DeleteLifecycleListener)
            {
                ((DeleteLifecycleListener)listener.getListener()).postDelete(new InstanceLifecycleEvent(pc, InstanceLifecycleEvent.DELETE, null));
            }
        }
    }

    public void postDetach(Object pc, Object detachedPC)
    {
        if (pc instanceof DetachCallback)
        {
            ((DetachCallback) detachedPC).jdoPostDetach(pc);
        }
        Iterator iter = listeners.iterator();
        while (iter.hasNext())
        {
            LifecycleListenerForClass listener = (LifecycleListenerForClass) iter.next();
            if (listener.forClass(pc.getClass()) && listener.getListener() instanceof DetachLifecycleListener)
            {
                ((DetachLifecycleListener)listener.getListener()).postDetach(new InstanceLifecycleEvent(detachedPC, InstanceLifecycleEvent.DETACH, pc));
            }
        }
    }

    public void postDirty(Object pc)
    {
        Iterator iter = listeners.iterator();
        while (iter.hasNext())
        {
            LifecycleListenerForClass listener = (LifecycleListenerForClass) iter.next();
            if (listener.forClass(pc.getClass()) && listener.getListener() instanceof DirtyLifecycleListener)
            {
                ((DirtyLifecycleListener)listener.getListener()).postDirty(new InstanceLifecycleEvent(pc, InstanceLifecycleEvent.DIRTY, null));
            }
        }
    }

    public void postLoad(Object pc)
    {
        if (pc instanceof LoadCallback)
        {
            ((LoadCallback) pc).jdoPostLoad();
        }
        Iterator iter = listeners.iterator();
        while (iter.hasNext())
        {
            LifecycleListenerForClass listener = (LifecycleListenerForClass) iter.next();
            if (listener.forClass(pc.getClass()) && listener.getListener() instanceof LoadLifecycleListener)
            {
                ((LoadLifecycleListener)listener.getListener()).postLoad(new InstanceLifecycleEvent(pc, InstanceLifecycleEvent.LOAD, null));
            }
        }
    }

    public void postStore(Object pc)
    {
        Iterator iter = listeners.iterator();
        while (iter.hasNext())
        {
            LifecycleListenerForClass listener = (LifecycleListenerForClass) iter.next();
            if (listener.forClass(pc.getClass()) && listener.getListener() instanceof StoreLifecycleListener)
            {
                ((StoreLifecycleListener)listener.getListener()).postStore(new InstanceLifecycleEvent(pc, InstanceLifecycleEvent.STORE, null));
            }
        }
    }

    public void preAttach(Object pc)
    {
        Iterator iter = listeners.iterator();
        while (iter.hasNext())
        {
            LifecycleListenerForClass listener = (LifecycleListenerForClass) iter.next();
            if (listener.forClass(pc.getClass()) && listener.getListener() instanceof AttachLifecycleListener)
            {
                ((AttachLifecycleListener)listener.getListener()).preAttach(new InstanceLifecycleEvent(pc, InstanceLifecycleEvent.ATTACH, null));
            }
        }
        if (pc instanceof AttachCallback)
        {
            ((AttachCallback) pc).jdoPreAttach();
        }
    }

    public void preClear(Object pc)
    {
        Iterator iter = listeners.iterator();
        while (iter.hasNext())
        {
            LifecycleListenerForClass listener = (LifecycleListenerForClass) iter.next();
            if (listener.forClass(pc.getClass()) && listener.getListener() instanceof ClearLifecycleListener)
            {
                ((ClearLifecycleListener)listener.getListener()).preClear(new InstanceLifecycleEvent(pc, InstanceLifecycleEvent.CLEAR, null));
            }
        }
        if (pc instanceof ClearCallback)
        {
            ((ClearCallback) pc).jdoPreClear();
        }
    }

    public void preDelete(Object pc)
    {
        Iterator iter = listeners.iterator();
        while (iter.hasNext())
        {
            LifecycleListenerForClass listener = (LifecycleListenerForClass) iter.next();
            if (listener.forClass(pc.getClass()) && listener.getListener() instanceof DeleteLifecycleListener)
            {
                ((DeleteLifecycleListener)listener.getListener()).preDelete(new InstanceLifecycleEvent(pc, InstanceLifecycleEvent.DELETE, null));
            }
        }

        if (pc instanceof DeleteCallback)
        {
            ((DeleteCallback) pc).jdoPreDelete();
        }
    }

    public void preDetach(Object pc)
    {
        Iterator iter = listeners.iterator();
        while (iter.hasNext())
        {
            LifecycleListenerForClass listener = (LifecycleListenerForClass) iter.next();
            if (listener.forClass(pc.getClass()) && listener.getListener() instanceof DetachLifecycleListener)
            {
                ((DetachLifecycleListener)listener.getListener()).preDetach(new InstanceLifecycleEvent(pc, InstanceLifecycleEvent.DETACH, null));
            }
        }
        if (pc instanceof DetachCallback)
        {
            ((DetachCallback) pc).jdoPreDetach();
        }        
    }

    public void preDirty(Object pc)
    {
        Iterator iter = listeners.iterator();
        while (iter.hasNext())
        {
            LifecycleListenerForClass listener = (LifecycleListenerForClass) iter.next();
            if (listener.forClass(pc.getClass()) && listener.getListener() instanceof DirtyLifecycleListener)
            {
                ((DirtyLifecycleListener)listener.getListener()).preDirty(new InstanceLifecycleEvent(pc, InstanceLifecycleEvent.DIRTY, null));
            }
        }
    }

    public void preStore(Object pc)
    {
        // Call any lifecycle listeners waiting for this event.
        Iterator iter = listeners.iterator();
        while (iter.hasNext())
        {
            LifecycleListenerForClass listener = (LifecycleListenerForClass) iter.next();
            if (listener.forClass(pc.getClass()) && listener.getListener() instanceof StoreLifecycleListener)
            {
                // PRE_STORE will return the fields being stored (JPOX extension)
                AbstractPersistenceManager pm = (AbstractPersistenceManager) ((PersistenceCapable)pc).jdoGetPersistenceManager();
                StateManager sm = pm.findStateManager((PersistenceCapable)pc);
                String[] fieldNames = sm.getDirtyFieldNames();
                if (fieldNames == null)
                {
                    // Must be persisting so just return all loaded fields
                    fieldNames = sm.getLoadedFieldNames();
                }
                ((StoreLifecycleListener)listener.getListener()).preStore(new FieldInstanceLifecycleEvent(pc, InstanceLifecycleEvent.STORE, null, fieldNames));
            }
        }
        if (pc instanceof StoreCallback)
        {
            ((StoreCallback) pc).jdoPreStore();
        }
    }

    public void addListener(Object listener, Class[] classes)
    {
        if (listener == null)
        {
            return;
        }
        if (listeners == null)
        {
            listeners = new ArrayList(1);
        }

        listeners.add(new LifecycleListenerForClass((InstanceLifecycleListener) listener, classes));
    }

    public void removeListener(Object listener)
    {
        if (listener != null && listeners != null)
        {
            // Remove from the PMF
            Iterator iter = listeners.iterator();
            while (iter.hasNext())
            {
                LifecycleListenerForClass classListener = (LifecycleListenerForClass) iter.next();
                if (classListener.getListener() == listener)
                {
                    iter.remove();
                }
            }
        }
    }
    
    public void close()
    {
        listeners.clear();
    }

    public void postRefresh(Object pc)
    {
        // do nothing; JDO does not invoke postLoad on refresh
        
    }
}
