/**********************************************************************
Copyright (c) 2005 Erik Bengtson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    ...
**********************************************************************/
package org.jpox.store;

import org.jpox.metadata.AbstractPropertyMetaData;
import org.jpox.metadata.DiscriminatorMetaData;
import org.jpox.metadata.ExtendableMetaData;
import org.jpox.metadata.VersionMetaData;
import org.jpox.store.mapping.JavaTypeMapping;

/**
 * This represents a container of fields. Such as table (container of columns), file, etc.
 * @version $Revision: 1.12 $
 */
public interface DatastoreContainerObject extends DatastoreObject
{
    /**
     * Method to add a new column to the internal representation.
     * @param storedJavaType The type of the Java field to store
     * @param name The name of the column
     * @param mapping The type mapping for this column
     * @param colmd The ExtendableMetaData (ColumnMetaData for RDBMS)
     * @return The new Column
     */
    DatastoreField addDatastoreField(String storedJavaType, DatastoreIdentifier name, JavaTypeMapping mapping, ExtendableMetaData colmd);
    
    /**
     * Checks if there is a DatastoreField for the identifier
     * @param identifier the identifier of the DatastoreField
     * @return true if the DatastoreField exists for the identifier
     */
    boolean hasDatastoreField(DatastoreIdentifier identifier);    

    /**
     * Accessor for the ID mapping of this container object.
     * @return The ID Mapping (if present)
     */
    JavaTypeMapping getIDMapping();
    

    /**
     * Accessor for the mapping for the specified FieldMetaData. A
     * datastore container object may store many fields.
     * @param fmd the FieldMetaData
     * @return The Mapping for the field, or null if the FieldMetaData cannot be found
     */
    JavaTypeMapping getFieldMapping(AbstractPropertyMetaData fmd);    

    /**
     * Accessor for Discriminator MetaData.
     * @return Returns the Discriminator MetaData.
     */
    DiscriminatorMetaData getDiscriminatorMetaData();

    /**
     * Accessor for the discriminator mapping specified.
     * @return The mapping for the discriminator datastore field
     **/
    JavaTypeMapping getDiscriminatorMapping();

    /**
     * Accessor for the Version MetaData.
     * @return Returns the Version MetaData.
     */
    VersionMetaData getVersionMetaData();

    /**
     * Accessor for the version mapping specified .
     * @return The version mapping.
     **/
    JavaTypeMapping getVersionMapping();

    /**
     * Accessor for the DatastoreFields infered from the java and metadata files.
     * @return the DatastoreField[]
     */
    DatastoreField[] getDatastoreFieldsMetaData();
    
}