/**********************************************************************
Copyright (c) 2002 Mike Martin (TJDO) and others. All rights reserved. 
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 

Contributors:
2003 Andy Jefferson - coding standards
    ...
**********************************************************************/
package org.jpox.store;


/**
 * A "second-class" object identifier.  SCOIDs are used as object identifiers
 * for classes that have no database extent, such as JPOXSQL result objects.
 *
 * <p>The only thing a SCOID tracks is the class of the instance being
 * identified.  Every SCOID is unique within the JVM, which effectively means
 * universally unique since Serializable is not implemented.
 *
 * @see OID
 * @version $Revision: 1.2 $
 */
public final class SCOID
{
    private String objClass;

    /**
     * Constructs a new SCOID to identify an object of the given class.
     *
     * @param objClass  The class of the instance being identified.
     */
    public SCOID(String objClass)
    {
        this.objClass = objClass;
    }

    /**
     * Returns the class of the object identified by this SCOID.
     *
     * @return  The class of the object identified by this SCOID.
     */
    public String getSCOClass()
    {
        return objClass;
    }
}
