/**********************************************************************
Copyright (c) 2002 Kelly Grizzle (TJDO) and others. All rights reserved. 
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License. 
 

Contributors:
2002 Mike Martin (TJDO)
2004 Andy Jefferson - removed dependency on JDK 1.4 (Boolean.valueOf(boolean))
2004 Andy Jefferson - updated type handling to use datastoreMappings
    ...
**********************************************************************/
package org.jpox.store.mapping;

import java.sql.Types;

import org.jpox.ClassLoaderResolver;
import org.jpox.store.expression.BooleanBitColumnExpression;
import org.jpox.store.expression.BooleanBitColumnLiteral;
import org.jpox.store.expression.BooleanCharColumnExpression;
import org.jpox.store.expression.BooleanCharColumnLiteral;
import org.jpox.store.expression.BooleanExpression;
import org.jpox.store.expression.BooleanLiteral;
import org.jpox.store.expression.LogicSetExpression;
import org.jpox.store.expression.QueryExpression;
import org.jpox.store.expression.ScalarExpression;
import org.jpox.store.rdbms.adapter.RDBMSAdapter;
import org.jpox.store.rdbms.mapping.RDBMSMapping;

/**
 * Mapping of Java Boolean object.
 *
 * @version $Revision: 1.19 $
 **/
public class BooleanMapping extends SingleFieldMapping implements SimpleDatastoreRepresentation
{
    private static Boolean mappingSampleValue = Boolean.TRUE;

    public Object getSampleValue(ClassLoaderResolver clr)
    {
        return mappingSampleValue;
    }

    public ScalarExpression newLiteral(QueryExpression qs, Object value)
    {
        ScalarExpression expr;
        // TODO Change this. We should NOT be using SQL types here. org.jpox.store is supposed to be datastore independent
        if (getNumberOfDatastoreFields() > 0)
        {
            RDBMSMapping data_mapping = (RDBMSMapping)getDataStoreMapping(0);
            switch (data_mapping.getTypeInfo().dataType)
            {
                case Types.BIT:
                case Types.NUMERIC:
                    if (((RDBMSAdapter)dba).isBitReallyBoolean())
                    {
                        expr = new BooleanLiteral(qs, this, ((Boolean)value).booleanValue());
                    }
                    else
                    {
                        expr = new BooleanBitColumnLiteral(qs, this, ((Boolean)value).booleanValue());
                    }
                	break;
                case Types.BOOLEAN: // JDBC 3.0
                    expr = new BooleanLiteral(qs, this, ((Boolean)value).booleanValue());
                    break;
                case Types.CHAR:
                    expr = new BooleanCharColumnLiteral(qs, this, ((Boolean)value).booleanValue());
                	break;
                default:
                    expr = new BooleanLiteral(qs, this, ((Boolean)value).booleanValue());
            }
        }
        else
        {
            expr = new BooleanLiteral(qs, this, ((Boolean)value).booleanValue());
        }
        return expr;
    }

    public ScalarExpression newScalarExpression(QueryExpression qs, LogicSetExpression te)
    {
        ScalarExpression expr;
        RDBMSMapping data_mapping = (RDBMSMapping)getDataStoreMapping(0);
        // TODO Change this. We should NOT be using SQL types here. org.jpox.store is supposed to be datastore independent
        switch (data_mapping.getTypeInfo().dataType)
        {
            case Types.BIT:
            case Types.NUMERIC:
                if (((RDBMSAdapter)dba).isBitReallyBoolean())
                {
                    expr = new BooleanExpression(qs, this, te);
                }
                else
                {
                    expr = new BooleanBitColumnExpression(qs, this, te);
                }
            	break;
            case Types.BOOLEAN: // JDBC 3.0
                expr = new BooleanExpression(qs, this, te);
                break;
            case Types.CHAR:
                expr = new BooleanCharColumnExpression(qs, this, te);
            	break;
            default:
                expr = new BooleanExpression(qs, this, te);
        }

        return expr; 
    }

    /**
     * Accessor for the Java type being represented here.
     * @return The Java type
     */
    public Class getJavaType()
    {
        return Boolean.class;
    }
}