/**********************************************************************
Copyright (c) 2002 Mike Martin (TJDO) and others. All rights reserved. 
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License. 
 

Contributors:
2003 Andy Jefferson - coding standards
    ...
**********************************************************************/
package org.jpox.store.mapping;

import org.jpox.StateManager;

/**
 * Representation for Mapping callbacks within JDO.
 *
 * @version $Revision: 1.3 $
 **/
public interface MappingCallbacks
{
    /**
     * Method called after the insert of objects so that additional operations can be performed
     * if necessary.
     * @param sm StateManager of the owner
     */
    void postInsert(StateManager sm);

    /**
     * Method called after the retrieval of objects, so that additional operations can be
     * performed if necessary.
     * @param sm StateManager of the owner
     */
    void postFetch(StateManager sm);

    /**
     * Method called after the update of objects, so that additional operations can be
     * performed if necessary.
     * @param sm StateManager of the owner
     */
    void postUpdate(StateManager sm);

    /**
     * Method called before the delete of objects, so that additional operations can be
     * performed if necessary.
     * @param sm StateManager of the owner
     */
    void preDelete(StateManager sm);

    /**
     * Clear the collection and delete child dependent elements, values or keys
     * that are tagged as dependent.
     * @param sm the owner StateManager
     */
    void deleteDependent(StateManager sm);
}