/**********************************************************************
Copyright (c) 2002 Mike Martin (TJDO) and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    Andy Jefferson - coding standards and javadocs
    ...
**********************************************************************/
package org.jpox.store.mapping;

import java.sql.Date;

import org.jpox.ClassLoaderResolver;
import org.jpox.store.expression.LogicSetExpression;
import org.jpox.store.expression.QueryExpression;
import org.jpox.store.expression.ScalarExpression;
import org.jpox.store.expression.SqlDateLiteral;
import org.jpox.store.expression.SqlTemporalExpression;

/**
 * SCO Mapping for an SQLDate type.
 * Maps between a java.sql.Date object and an SQL "DATE" type in the datatsore. 
 *
 * @version $Revision: 1.13 $
 **/
public class SqlDateMapping extends SingleFieldMapping implements SimpleDatastoreRepresentation
{
    private static java.sql.Date mappingSampleValue = new java.sql.Date(new java.util.Date().getTime());

    public Object getSampleValue(ClassLoaderResolver clr)
    {
        return mappingSampleValue;
    }

    public ScalarExpression newLiteral(QueryExpression qs, Object value)
    {
        ScalarExpression expr = new SqlDateLiteral(qs, this, (Date)value);
        return expr; 
    }

    public ScalarExpression newScalarExpression(QueryExpression qs, LogicSetExpression te)
    {
        ScalarExpression expr = new SqlTemporalExpression(qs, this, te);
        return expr; 
    }

    public Class getJavaType()
    {
        return java.sql.Date.class;
    }
}