/**********************************************************************
Copyright (c) 2006 Andy Jefferson and others. All rights reserved. 
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    ...
**********************************************************************/
package org.jpox.store.query;

import org.jpox.PersistenceManager;

/**
 * An object that reads result set rows and returns corresponding persistent
 * objects from them.  Different queries accomplish this in different ways,
 * so a query supplies a suitable ResultObjectFactory to each QueryResult
 * when it is executed. The QueryResult only uses it to turn ResultSet rows
 * into objects and otherwise manages the ResultSet itself.
 * 
 * @see QueryResult
 * @version $Revision: 1.1 $
 */
public interface ResultObjectFactory
{
    /**
     * Instantiates a persistent object instance from the current row of
     * the given result set.
     *
     * @param pm The PersistenceManager.
     * @param rs The result set. The contents of the current row are used to 
     *     locate or create a corresponding persistent object instance.
     * @param pcClass The PersistenceCapable class
     * @return  A persistent object instance.
     */
    Object getObject(PersistenceManager pm, Object rs, Class pcClass);
}