/**********************************************************************
Copyright (c) 2006 Andy Jefferson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    ...
**********************************************************************/
package org.jpox.store.rdbms;

import java.sql.Connection;
import java.sql.SQLException;

import org.jpox.Transaction;

/**
 * Extension of SUN's JDO Transaction for RDBMS datastores.
 *
 * @version $Revision: 1.1 $
 **/ 
public interface RDBMSTransaction extends Transaction
{
    /**
     * Checks whether a connection to the datasource is open.
     * @return true if the Connection is open
     */
    boolean isConnectionOpen();

    /**
     * Accessor for the connection to the datasource.
     * @param forWriting Whether the connection is read-only or read-write.
     * @param forQuery Whether the connection is to be used by a query (i.e.JDOQUERY).
     * @return The Connection
     * @throws SQLException
     */    
    Connection getConnection(boolean forWriting, boolean forQuery) throws SQLException;

    /**
     * Accessor for the connection to the datasource.
     * @param forWriting Whether the connection is read-only or read-write.
     * @param forQuery Whether the connection is to be used by a query (i.e.JDOQUERY).
     * @param useOpenedConnection whether to use an already opened connection, if one is opened. 
     * @return The Connection
     * @throws SQLException
     */
    Connection getConnection(boolean forWriting, boolean forQuery, boolean useOpenedConnection) throws SQLException;

    /**
     * Method to release the Connection.
     * @param conn The Connection to release.
     * @throws SQLException Thrown when an error occurs releasing the
     * connection.
     **/    
    void releaseConnection(Connection conn) throws SQLException;

    /**
     * Accessor for the transaction isolation level.
     * @return The transaction isolation level.
     **/
    int getTransactionIsolation();

    /**
     * Mutator for the transaction isolation level.
     * @param isolationLevel The isolation level required.
     **/
    void setTransactionIsolation(int isolationLevel);

    /**
     * Accessor for whether to use an update lock when fetching data.
     * Will return false if isolation levels of TRANSACTION_REPEATABLE_READ
     * or TRANSACTION_SERIALIZABLE are selected. Otherwise returns the local
     * settings of the useUpdateLock flag.
     * @return Whether to use an update lock.
     **/
    boolean useUpdateLockOnFetch();

    /**
     * Mutator for whether to lock queried/fetched objects in this txn.
     * @param lock Whether to use an update lock.
     **/
    void setUseUpdateLock(boolean lock);
}