/**********************************************************************
Copyright (c) 2003 Mike Martin and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    Andy Jefferson - coding standards
    ...
**********************************************************************/
package org.jpox.store.rdbms.exceptions;

import javax.jdo.JDOFatalInternalException;

import org.jpox.store.rdbms.Column;
import org.jpox.util.Localiser;

/**
 * A <tt>DuplicateColumnNameException</tt> is thrown if an attempt is made to
 * add a column to a table with a name already in-use by an existing column.
 *
 * @version $Revision: 1.2 $
 */
public class DuplicateColumnNameException extends JDOFatalInternalException
{
    private static final Localiser LOCALISER=Localiser.getInstance("org.jpox.store.rdbms.Localisation");

    /** Column that cannot be created because it conflicts with an existing column with the same identifier. */
    private Column conflictingColumn;

    /**
     * Constructs a duplicate column name exception.
     * @param tableName Name of the table being initialized.
     * @param column Column we already have
     * @param conflictingColumn Column that we tried to create
     */
    public DuplicateColumnNameException(String tableName, Column column, Column conflictingColumn)
    {
        super(LOCALISER.msg("RDBMS.Exception.DuplicateColumnName", column.getIdentifier(), tableName,
            column.getMapping().getFieldMetaData() == null ?
                LOCALISER.msg("RDBMS.Exception.DuplicateColumnNameUnknownSource"):column.getMapping().getFieldMetaData().getFullFieldName(),
            conflictingColumn.getMapping().getFieldMetaData() == null ?
                LOCALISER.msg("RDBMS.Exception.DuplicateColumnNameUnknownSource"):conflictingColumn.getMapping().getFieldMetaData().getFullFieldName()));
        this.conflictingColumn = conflictingColumn;
    }

    /**
     * Accessor for the column that could not be created because it conflicts with something already present.
     * @return The column
     */
    public Column getConflictingColumn()
    {
        return conflictingColumn;
    }
}