/**********************************************************************
Copyright (c) 2002 Mike Martin and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    Andy Jefferson - coding standards
    ...
**********************************************************************/
package org.jpox.store.rdbms.exceptions;

import org.jpox.store.exceptions.DatastoreValidationException;
import org.jpox.store.rdbms.Column;
import org.jpox.store.rdbms.JDBCUtils;
import org.jpox.util.Localiser;

/**
 * A <tt>IncompatibleDataTypeException</tt> is thrown if a column is detected to
 * have an incompatible type in the database during schema validation.
 *
 * @see Column
 * @version $Revision: 1.4 $ 
 */
public class IncompatibleDataTypeException extends DatastoreValidationException
{
    private static final Localiser LOCALISER_RDBMS=Localiser.getInstance("org.jpox.store.rdbms.Localisation");

    /**
     * Constructs an incompatible data type exception.
     * @param column        The column having an incompatible data type.
     * @param expectedType  The expected java.sql.Type of the column taken from the metadata.
     * @param actualType    The actual java.sql.Type of the column taken from the database.
     */
    public IncompatibleDataTypeException(Column column, int expectedType, int actualType)
    {
        super(LOCALISER_RDBMS.msg("RDBMS.Exception.IncompatibleDataType", column, 
            JDBCUtils.getNameForJDBCType(actualType), JDBCUtils.getNameForJDBCType(expectedType)));
    }
}