/**********************************************************************
Copyright (c) 2002 Mike Martin and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    Andy Jefferson - coding standards
    ...
**********************************************************************/
package org.jpox.store.rdbms.exceptions;

import org.jpox.store.exceptions.DatastoreValidationException;
import org.jpox.store.rdbms.table.Table;
import org.jpox.util.Localiser;

/**
 * A <tt>NotAViewException</tt> is thrown during schema validation if a
 * table should be a view but is found not to be in the database.
 *
 * @version $Revision: 1.3 $ 
 */
public class NotAViewException extends DatastoreValidationException
{
    private static final Localiser LOCALISER_RDBMS=Localiser.getInstance("org.jpox.store.rdbms.Localisation");

    /**
     * Constructs a not-a-view exception.
     * @param viewName Name of the view that is of the wrong type.
     * @param type the type of the object @see {@link Table}
     */
    public NotAViewException(String viewName, int type)
    {
        super(LOCALISER_RDBMS.msg("RDBMS.Exception.NotAView",viewName,""+type));
    }
}