/**********************************************************************
Copyright (c) 2002 Mike Martin (TJDO) and others. All rights reserved. 
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    Andy Jefferson - coding standards
    ...
**********************************************************************/
package org.jpox.store.rdbms.fieldmanager;

import java.sql.ResultSet;

import org.jpox.PersistenceManager;
import org.jpox.StateManager;
import org.jpox.store.StatementExpressionIndex;
import org.jpox.store.fieldmanager.AbstractFieldManager;
import org.jpox.store.mapping.EmbeddedPCMapping;
import org.jpox.store.mapping.JavaTypeMapping;
import org.jpox.store.mapping.SerialisedReferenceMapping;
import org.jpox.store.mapping.SerialisedPCMapping;

/**
 * ResultSet getter implementation of a field manager.
 *
 * @version $Revision: 1.8 $
 **/
public class ResultSetGetter extends AbstractFieldManager
{
    private final StateManager sm;
    private final PersistenceManager pm;
    private final ResultSet rs;
    private final StatementExpressionIndex[] statementExpressionIndex;

    /**
     * Constructor
     * @param sm the StateManager
     * @param rs the ResultSet
     * @param statementExpressionIndex the StatementExpressionIndex
     */
    public ResultSetGetter(StateManager sm, ResultSet rs, StatementExpressionIndex[] statementExpressionIndex)
    {
        this.sm = sm;
        this.pm = sm.getPersistenceManager();
        this.rs = rs;
        this.statementExpressionIndex = statementExpressionIndex;
    }

    public boolean fetchBooleanField(int fieldNumber)
    {
        return statementExpressionIndex[fieldNumber].getMapping().getBoolean(pm, rs, statementExpressionIndex[fieldNumber].getExpressionIndex());
    }

    public char fetchCharField(int fieldNumber)
    {
        return statementExpressionIndex[fieldNumber].getMapping().getChar(pm, rs, statementExpressionIndex[fieldNumber].getExpressionIndex());
    }

    public byte fetchByteField(int fieldNumber)
    {
        return statementExpressionIndex[fieldNumber].getMapping().getByte(pm, rs, statementExpressionIndex[fieldNumber].getExpressionIndex());
    }

    public short fetchShortField(int fieldNumber)
    {
        return statementExpressionIndex[fieldNumber].getMapping().getShort(pm, rs, statementExpressionIndex[fieldNumber].getExpressionIndex());
    }

    public int fetchIntField(int fieldNumber)
    {
        return statementExpressionIndex[fieldNumber].getMapping().getInt(pm, rs, statementExpressionIndex[fieldNumber].getExpressionIndex());
    }

    public long fetchLongField(int fieldNumber)
    {
        return statementExpressionIndex[fieldNumber].getMapping().getLong(pm, rs, statementExpressionIndex[fieldNumber].getExpressionIndex());
    }

    public float fetchFloatField(int fieldNumber)
    {
        return statementExpressionIndex[fieldNumber].getMapping().getFloat(pm, rs, statementExpressionIndex[fieldNumber].getExpressionIndex());
    }

    public double fetchDoubleField(int fieldNumber)
    {
        return statementExpressionIndex[fieldNumber].getMapping().getDouble(pm, rs, statementExpressionIndex[fieldNumber].getExpressionIndex());
    }

    public String fetchStringField(int fieldNumber)
    {
        return statementExpressionIndex[fieldNumber].getMapping().getString(pm, rs, statementExpressionIndex[fieldNumber].getExpressionIndex());
    }

    public Object fetchObjectField(int fieldNumber)
    {
        JavaTypeMapping mapping = statementExpressionIndex[fieldNumber].getMapping();
        Object value;
        if (mapping instanceof EmbeddedPCMapping ||
            mapping instanceof SerialisedPCMapping ||
            mapping instanceof SerialisedReferenceMapping)
        {
            value = mapping.getObject(pm, rs, statementExpressionIndex[fieldNumber].getExpressionIndex(), sm, fieldNumber);
        }
        else
        {
            value = mapping.getObject(pm, rs, statementExpressionIndex[fieldNumber].getExpressionIndex());
        }

        return sm.newSCOInstance(fieldNumber, value, false);
    }
}