/**********************************************************************
Copyright (c) 2006 Andy Jefferson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    ...
**********************************************************************/
package org.jpox.store.rdbms.mapping.oracle;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectOutputStream;
import java.util.Collection;

import javax.jdo.JDODataStoreException;
import javax.jdo.JDOObjectNotFoundException;

import org.jpox.StateManager;
import org.jpox.store.mapping.CollectionMapping;

/**
 * Oracle variant of the CollectionMapping for cases where we are serialising
 * the field into a single column. This is necessary so we can intercept perform
 * any necessary postInsert, postUpdate nonsense for inserting BLOBs
 * 
 * @version $Revision: 1.3 $
 */
public class OracleCollectionMapping extends CollectionMapping
{
    /**
     * Retrieve the empty BLOB created by the insert statement and write out the
     * current BLOB field value to the Oracle BLOB object.
     * @param sm the current StateManager
     * @throws JDOObjectNotFoundException
     * @throws JDODataStoreException
     */
    public void postInsert(StateManager sm)
    {
        if (containerIsStoredInSingleColumn())
        {
            Collection value = (Collection) sm.provideField(fmd.getAbsoluteFieldNumber());

            // Check that the elements are not managed by other PM, or are not yet persisted
            validateElementsForWriting(sm, value); // Why do this ? We are storing them serialised/embedded in a single col!

            // Generate the contents for the BLOB
            byte[] bytes = new byte[0];
            if (value != null)
            {
                try
                {
                    ByteArrayOutputStream baos = new ByteArrayOutputStream();
                    ObjectOutputStream oos = new ObjectOutputStream(baos);
                    oos.writeObject(value);
                    bytes = baos.toByteArray();
                }
                catch (IOException e1)
                {
                    // Do Nothing
                }
            }

            // Update the BLOB
            OracleBlobRDBMSMapping.updateBlobColumn(sm, getDatastoreContainer(), getDataStoreMapping(0), bytes);
        }
        else
        {
            super.postInsert(sm);
        }
    }

    /**
     * @see org.jpox.store.mapping.MappingCallbacks#postUpdate(org.jpox.StateManager)
     */
    public void postUpdate(StateManager sm)
    {
        if (containerIsStoredInSingleColumn())
        {
            Collection value = (Collection) sm.provideField(fmd.getAbsoluteFieldNumber());

            // Check that the elements are not managed by other PM, or are not yet persisted
            validateElementsForWriting(sm,value); // Why do this ? We are storing them serialised/embedded in a single col!

            postInsert(sm);
        }
        else
        {
            super.postUpdate(sm);
        }
    }
}