/******************************************************************
Copyright (c) 2004 Erik Bengtson and others. All rights reserved. 
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
2004 Andy Jefferson - moved getMapping() from OracleDatabaseAdapter
2005 Andy Jefferson - changed to extend RDBMSMappingManager
2006 Andy Jefferson - added override mapping classes method
2006 Andy Jefferson - moved all mappings to plugin.xml
    ...
*****************************************************************/
package org.jpox.store.rdbms.mapping.oracle;

import org.jpox.metadata.AbstractPropertyMetaData;
import org.jpox.store.mapping.ArrayMapping;
import org.jpox.store.mapping.BitSetMapping;
import org.jpox.store.mapping.CollectionMapping;
import org.jpox.store.mapping.MapMapping;
import org.jpox.store.mapping.SerialisedMapping;
import org.jpox.store.mapping.SerialisedPCMapping;
import org.jpox.store.mapping.StringMapping;
import org.jpox.store.rdbms.mapping.RDBMSMappingManager;

/**
 * Mapping manager for Oracle RDBMS adapters.
 * 
 * @version $Revision: 1.6 $
 */
public class OracleRDBMSMappingManager extends RDBMSMappingManager
{
    /**
     * Constructor.
     */
    public OracleRDBMSMappingManager()
    {
    }

    /**
     * Method to allow overriding of mapping classes
     * @param mappingClass The mapping class
     * @param fmd Field meta data for the field (if appropriate)
     * @return The mapping class to use
     */
    protected Class getOverrideMappingClass(Class mappingClass, AbstractPropertyMetaData fmd)
    {
        // Override some mappings with Oracle-specific mappings
        if (mappingClass.equals(BitSetMapping.class))
        {
            return OracleBitSetMapping.class;
        }
        else if (mappingClass.equals(StringMapping.class))
        {
            if (fmd != null && fmd.getColumnMetaData() != null && fmd.getColumnMetaData().length > 0)
            {
                String jdbcType = fmd.getColumnMetaData()[0].getJdbcType();
                if (jdbcType != null && jdbcType.toLowerCase().indexOf("clob") >= 0)
                {
                    // CLOB, so use OracleString
                    return OracleStringMapping.class;
                }
            }
            return mappingClass;
        }
        else if (mappingClass.equals(SerialisedMapping.class))
        {
            return OracleSerialisedObjectMapping.class;
        }
        else if (mappingClass.equals(SerialisedPCMapping.class))
        {
            return OracleSerialisedPCMapping.class;
        }
        else if (mappingClass.equals(ArrayMapping.class))
        {
            return OracleArrayMapping.class;
        }
        else if (mappingClass.equals(MapMapping.class))
        {
            return OracleMapMapping.class;
        }
        else if (mappingClass.equals(CollectionMapping.class))
        {
            return OracleCollectionMapping.class;
        }
        else
        {
            return mappingClass;
        }
    }
}