/**********************************************************************
Copyright (c) 2005 Brendan De Beer and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License. 


Contributors:
    ...
 **********************************************************************/
package org.jpox.store.rdbms.mapping.oracle;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectOutputStream;

import javax.jdo.JDODataStoreException;
import javax.jdo.JDOObjectNotFoundException;

import org.jpox.StateManager;
import org.jpox.store.mapping.MappingCallbacks;
import org.jpox.store.mapping.SerialisedMapping;
import org.jpox.util.Localiser;

/**
 * Mapping for Object and Serializable types.
 *
 * @version $Revision: 1.12 $
 */
public class OracleSerialisedObjectMapping extends SerialisedMapping implements MappingCallbacks
{
    /** Localiser for messages. */
    protected static final Localiser LOCALISER_RDBMS = Localiser.getInstance("org.jpox.store.rdbms.Localisation");

    /**
     * @see org.jpox.store.mapping.MappingCallbacks#deleteDependent(org.jpox.StateManager)
     */
    public void deleteDependent(StateManager sm)
    {
    }

    /**
     * @see org.jpox.store.mapping.MappingCallbacks#postFetch(org.jpox.StateManager)
     */
    public void postFetch(StateManager sm)
    {
    }

    /**
     * Retrieve the empty BLOB created by the insert statement and write out the
     * current BLOB field value to the Oracle BLOB object
     * @param sm the current StateManager
     * @throws JDOObjectNotFoundException
     * @throws JDODataStoreException
     */
    public void postInsert(StateManager sm)
    {
        // Generate the contents for the BLOB
        byte[] bytes = new byte[0];
        Object value = sm.provideField(fmd.getAbsoluteFieldNumber());
        if (value != null)
        {
            try
            {
                ByteArrayOutputStream baos = new ByteArrayOutputStream();
                ObjectOutputStream oos = new ObjectOutputStream(baos);
                oos.writeObject(value);
                bytes = baos.toByteArray();
            }
            catch (IOException e1)
            {
                // Do Nothing
            }
        }

        // Update the BLOB
        OracleBlobRDBMSMapping.updateBlobColumn(sm, getDatastoreContainer(), getDataStoreMapping(0), bytes);
    }

    /**
     * @see org.jpox.store.mapping.MappingCallbacks#postUpdate(org.jpox.StateManager)
     */
    public void postUpdate(StateManager sm)
    {
        postInsert(sm);
    }

    /**
     * @see org.jpox.store.mapping.MappingCallbacks#preDelete(org.jpox.StateManager)
     */
    public void preDelete(StateManager sm)
    {
    }
}