/**********************************************************************
Copyright (c) 2002 Kelly Grizzle (TJDO) and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 

Contributors:
2002 Mike Martin (TJDO)
2003 Andy Jefferson - coding standards
2004 Erik Bengtson - changed to use EMPTY_CLOB approach
2006 Andy Jefferson - use commonised CLOB method
    ...
**********************************************************************/
package org.jpox.store.rdbms.mapping.oracle;

import org.jpox.StateManager;
import org.jpox.store.mapping.MappingCallbacks;
import org.jpox.store.mapping.StringMapping;
import org.jpox.store.rdbms.adapter.RDBMSAdapter;

/**
 * Mapping for a String type for Oracle when stored in a CLOB column.
 *
 * @version $Revision: 1.13 $
 **/
public class OracleStringMapping extends StringMapping implements MappingCallbacks
{
    /**
     * Retrieve the empty CLOB locator created by the insert statement
     * and write out the current CLOB field value to the Oracle CLOB object
     * @param sm The StateManager owner of this field
     */
    public void postInsert(StateManager sm)
    {
        // Generate the contents for the CLOB
        String value = (String)sm.provideField(fmd.getAbsoluteFieldNumber());
        if (value == null)
        {
            value = "";
        }
        else if (value.length() == 0)
        {
            value = ((RDBMSAdapter) dba).getSurrogateForEmptyStrings();
        }

        // Update CLOB value
        OracleClobRDBMSMapping.updateClobColumn(sm, getDatastoreContainer(), getDataStoreMapping(0), value);
    }
    
    public void deleteDependent(StateManager sm)
    {
    }

    public void postFetch(StateManager sm)
    {
    }

    public void postUpdate(StateManager sm)
    {
        postInsert(sm);
    }

    public void preDelete(StateManager sm)
    {
    }
}