/**********************************************************************
Copyright (c) 2002 Mike Martin and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    Andy Jefferson - coding standards
    ...
**********************************************************************/
package org.jpox.store.rdbms.typeinfo;

import java.sql.ResultSet;


/**
 * Represents the metadata of a table's foreign key column in PostgreSQL.
 *
 * @version $Revision: 1.2 $ 
 */
public class PostgreSQLForeignKeyInfo extends ForeignKeyInfo
{
    /**
     * Constructs a foreign key information object from the current row of the
     * given result set.
     * The {@link ResultSet} object passed must have been obtained from a call
     * to DatabaseMetaData.getImportedKeys()
     * or DatabaseMetaData.getExportedKeys().
     *
     * <p>This method only retrieves the values from the current row; the
     * caller is required to advance to the next row with
     * {@link ResultSet#next}.
     *
     * @param rs The result set returned from
     * DatabaseMetaData.getImportedKeys()/DatabaseMetaData.getExportedKeys()
     */
    public PostgreSQLForeignKeyInfo(ResultSet rs)
    {
        super(rs);

        /*
         * The PostgreSQL drivers sometimes produce some truly funky metadata.
         * In this case, the FK_NAME column has been known to have miscellaneous
         * other strings dangling off the end of it separated by "\000", as in
         *
         *    WIDGET_FK1\000WIDGET\000BLAH ...
         *
         * instead of:
         *
         *    WIDGET_FK1
         */
        int firstBackslashIdx = fkName.indexOf('\\');

        if (firstBackslashIdx > 0)
        {
            fkName = fkName.substring(0, firstBackslashIdx);
        }
    }
}
