/**********************************************************************
Copyright (c) 2005 Erik Bengtson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 

Contributors:
    ...
**********************************************************************/
package org.jpox.util;

import java.sql.Connection;
import java.sql.SQLException;

import javax.sql.DataSource;

/**
 * Utility class for Failover
 * @version $Revision: 1.3 $
 */
public class FailoverUtils
{
    /**
     * Obtain a connection from the datasources, starting on the first datasource
     * until the last one in the list in case is not able to obtain the connection. 
     * @param ds the array of datasources
     * @param failOnError if fail on first error found, or only on the last one if unable to obtain the connection
     * @return the Connection or null if <code>ds</code> is null
     * @throws SQLException
     */
    public static Connection getConnection(DataSource[] ds, boolean failOnError)
    throws SQLException
    {
        if (ds == null)
        {
            return null;
        }
        for (int i = 0; i < ds.length; i++)
        {
            try
            {
                return ds[i].getConnection();
            }
            catch (SQLException e)
            {
                if (failOnError || i == ds.length - 1)
                {
                    throw e;
                }
            }
        }
        return null;
    }

    /**
     * Obtain a connection from the datasources, starting on the first datasource
     * until the last one in the list in case is not able to obtain the connection. 
     * @param ds the array of datasources
     * @param user User name for the connection
     * @param password Password for the conection
     * @param failOnError if fail on first error found, or only on the last one if unable to obtain the connection
     * @return the Connection or null if <code>ds</code> is null
     * @throws SQLException
     */
    public static Connection getConnection(DataSource[] ds, String user, String password, boolean failOnError)
    throws SQLException
    {
        if (ds == null)
        {
            return null;
        }
        for (int i = 0; i < ds.length; i++)
        {
            try
            {
                return ds[i].getConnection(user, password);
            }
            catch (SQLException e)
            {
                if (failOnError || i == ds.length - 1)
                {
                    throw e;
                }
            }
        }
        return null;
    }
}